@@ -227,13 +227,14 @@ namespace TreeTools {
       const Rcpp::IntegerVector parent,
       const Rcpp::IntegerVector child)
   {
-    if (2.0 * (2 + child.length()) > double(INT_FAST32_MAX)) {
+    if (R_xlen_t(2LL + child.length() + 2LL + child.length()) > R_xlen_t(INT_FAST32_MAX)) {
       Rcpp::stop("Too many edges in tree: "                        // #nocov
                  "Contact 'TreeTools' maintainer for support.");   // #nocov
     }
-
+    
+    ASSERT(parent.length() < INT_FAST32_MAX - 2);
     const int32
-      n_edge = parent.length(),
+      n_edge = int32(parent.length()),
       node_limit = n_edge + 2
     ;
 
@@ -312,13 +313,15 @@ namespace TreeTools {
       const Rcpp::IntegerVector child,
       const Rcpp::DoubleVector weight)
   {
-    if (2.0 * (2 + child.length()) > double(INT_FAST32_MAX)) {
+    if (R_xlen_t(2LL + child.length() + 2LL + child.length()) >
+          R_xlen_t(INT_FAST32_MAX)) {
       Rcpp::stop("Too many edges in tree: "                        // #nocov
                  "Contact 'TreeTools' maintainer for support.");   // #nocov
     }
     
+    ASSERT(parent.length() < INT_FAST32_MAX - 2);
     const int32
-      n_edge = parent.length(),
+      n_edge = int32(parent.length()),
       node_limit = n_edge + 2
     ;
     
